@@ -150,6 +150,7 @@ class VPreLex {
     int		m_keepComments;		///< Emit comments in output text
     int		m_keepWhitespace;	///< Emit all whitespace in output text
     bool	m_pedantic;	///< Obey standard; don't Substitute `error
+    bool	m_synthesis;	///< Remove translate_offs
 
     // State from lexer
     int		m_formalLevel;	///< Parenthesis counting inside def formals
@@ -164,6 +165,7 @@ class VPreLex {
 	m_keepComments = 0;
 	m_keepWhitespace = 1;
 	m_pedantic = false;
+	m_synthesis = false;
 	m_formalLevel = 0;
 	m_parenLevel = 0;
 	m_defCmtSlash = false;
